using Vo;
using Microsoft.AspNetCore.Mvc;
using Model;
using Services;
using Model.Base;
using Vo.Admin;
using Mapster;
using Infrastructure;


namespace Controllers.Admin
{
    /// <summary>
    /// PriProject)Controller
    /// </summary>
    // [ApiExplorerSettings(GroupName = "PriProject")]
    public class PriProjectController : BaseController
    {
        /// <summary>
        /// api分组接口
        /// </summary>
        private readonly IPriProjectService _PriProjectService;


        public PriProjectController(IPriProjectService PriProjectService)
        {
            _PriProjectService = PriProjectService;

        }

          /// <param name="page">分页参数</param>
        /// <summary>
        /// 列表
        /// </summary>
        /// <param name="page">分页对象</param>
        /// <param name="param">参数请求体</param>
        /// <returns>列表</returns>
        [HttpGet]
        [Route("/v1/pri/PriProject/getPriProjectList")]
        public IActionResult getPriProjectList([FromQuery] PagerInfo page, [FromQuery] PriProject param)
        {
            var response = _PriProjectService.getPriProjectList(page, param);
            return SUCCESS(response);
        }


        /// <summary>
        /// 详情
        /// </summary>
        /// <param name="param">参数请求体</param>
        /// <returns>详情</returns>
        [HttpGet]
        [Route("/v1/pri/PriProject/getPriProjectQuery")]
        public IActionResult getPriProjectQuery([FromQuery] PriProject param)
        {
            var response = _PriProjectService.GetFirst(m => m.id == param.id).Adapt<GetPriProjectQueryVo>();
            return SUCCESS(response);
        }


        /// <summary>
        /// 添加
        /// </summary>
        /// <param name="param">参数请求体</param>
        /// <returns>添加</returns>
        [HttpPost]
        [Route("/v1/pri/PriProject/addPriProject")]
        public IActionResult addPriProject([FromBody] PriProject param)
        {
            var modal = param.Adapt<PriProject>().ToCreate(HttpContext);
            var response = _PriProjectService.Add(modal);
            return SUCCESS(response);
        }


        /// <summary>
        /// 修改
        /// </summary>
        /// <param name="param">参数请求体</param>
        /// <returns>修改</returns>
        [HttpPut]
        [Route("/v1/pri/PriProject/updatePriProject")]
        public IActionResult updatePriProject([FromBody] PriProject param)
        {
            var modal = param.Adapt<PriProject>().ToCreate(HttpContext);
            var response = _PriProjectService.Update(modal);
            return SUCCESS(response);
        }


        /// <summary>
        /// 删除
        /// </summary>
        /// <param name="id">ID</param>
        /// <returns>删除</returns>
        [HttpDelete]
        [Route("/v1/pri/PriProject/deletePriProject/{id}")]
        public IActionResult deletePriProject(int id)
        {
            var response = _PriProjectService.Delete(id);
            return SUCCESS(response);
        }


          /// <param name="page">分页参数</param>
        /// <summary>
        /// 下拉框数据
        /// </summary>
        /// <param name="page">分页对象</param>
        /// <returns>下拉框数据</returns>
        [HttpGet]
        [Route("/v1/pri/PriProject/getPriProjectDic")]
        public IActionResult getPriProjectDic([FromQuery] PagerInfo page)
        {
            var response = _PriProjectService.getPriProjectDic(page);
            return SUCCESS(response);
        }




    }
}