using Attribute;
using Model;
using Model.Base;
using Repository;
using Service;
using Microsoft.AspNetCore.Mvc;
using Vo.Admin;


namespace Services
{
    /// <summary>
    /// 请求和响应日志Service业务层处理
    /// </summary>
    [AppService(ServiceType = typeof(IPriRequestLogService), ServiceLifetime = LifeTime.Transient)]
    public class PriRequestLogService : BaseService<PriRequestLog>, IPriRequestLogService
    {
        /// <summary>
        /// 请求和响应日志-列表
        /// </summary>
        /// <param name="param">参数请求体</param>
        /// <param name="page">分页参数</param>
        /// <returns>列表</returns>
        public PagedInfo<GetPriRequestLogListVo> getPriRequestLogList([FromQuery] PagerInfo page, [FromQuery] PriRequestLog param)
        {
            //拼装查询条件
            var predicate = Expressionable.Create<PriRequestLog>();
            predicate = predicate.AndIF(param.projectId > 0, m => m.projectId == param.projectId);
            predicate = predicate.AndIF(!string.IsNullOrEmpty(param.batchNo), m => m.batchNo.Contains(param.batchNo));
            var response = Queryable()
                .Where(predicate.ToExpression())
                .OrderByDescending(m => m.id)
                .ToPage<PriRequestLog, GetPriRequestLogListVo>(page);
            return response;
        }



    }
}
